==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/language/1/barnraiser_01/p_info.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'p_common.lang.php');

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_node_rules'] = 							"node rules";
$lang['hdr_administration'] = 						"administration";
$lang['hdr_credits'] = 								"credits";
$lang['hdr_about_aroundme'] = 						"about aroundme";
$lang['hdr_structure'] = 							"structure";
$lang['hdr_contact'] = 								"contact";
$lang['hdr_notes'] = 								"notes";


//BODY TEXT
$lang['txt_credits'] = 								"'aroundme' was conceived by Tom Calthrop, founder of Barnraiser and 'aroundme' project maintainer. Many thanks to the developers who have given time, energy and expertise to the aroundme project!";
$lang['txt_about_aroundme'] = 						"Barnraiser is an organisation dedicated to giving people the tools they need to share knowledge and further society through social software.<br /><p>As part of their mission they maintain 'aroundme', the software platform that this community is build upon.<br /></p><p>Visit Barnraiser at <a href=\"http://www.barnraiser.org/\" target=\"_new\">www.barnraiser.org</a> to find out more about their work.<br /></p>";
$lang['txt_contact'] = 								"place your organisations contact details here.";
$lang['txt_administration'] = 						"place information about the administrators here. Include a description of contact procedures.";
$lang['txt_structure'] = 							"describe the structure, goals and mission of your organisation. Divulge any information regarding policy, decision making procedure and structure that may affect the members rights.";
$lang['txt_notes'] = 								"place any notes or tips you wish to make to your membership.";

?>

==> aroundme_0_5_3.zip: aroundme_0_5_3/aroundme/language/1/barnraiser_01/p_info.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'p_common.lang.php');

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_node_rules'] = 							"node rules";
$lang['hdr_administration'] = 						"administration";
$lang['hdr_credits'] = 								"credits";
$lang['hdr_about_aroundme'] = 						"about aroundme";
$lang['hdr_structure'] = 							"structure";
$lang['hdr_contact'] = 								"contact";
$lang['hdr_notes'] = 								"notes";


//BODY TEXT
$lang['txt_credits'] = 								"aroundme was conceived by Tom Calthrop, founder of Barnraiser and 'aroundme' project maintainer. Many thanks to the developers who have given time, energy and expertise to the aroundme project!";
$lang['txt_about_aroundme'] = 						"Barnraiser is an organisation dedicated to giving people the tools they need to share knowledge and further society through social software.<br /><p>As part of their mission they maintain 'aroundme', the software platform that this community is build upon.<br /></p><p>Visit Barnraiser at <a href=\"http://www.barnraiser.org/\" target=\"_new\">www.barnraiser.org</a> to find out more about their work.<br /></p>";
$lang['txt_contact'] = 								"place your organisations contact details here.";
$lang['txt_administration'] = 						"place information about the administrators here. Include a description of contact procedures.";
$lang['txt_structure'] = 							"describe the structure, goals and mission of your organisation. Divulge any information regarding policy, decision making procedure and structure that may affect the members rights.";
$lang['txt_notes'] = 								"place any notes or tips you wish to make to your membership.";

?>
